@@ -3,7 +3,7 @@ package Perl::Critic::Community;
 use strict;
 use warnings;
 
-our $VERSION = 'v1.0.3';
+our $VERSION = 'v1.0.4';
 
 1;
 
@@ -124,6 +124,10 @@ Various modules with preferred alternatives
 
 Don't use function prototypes
 
+=item L<Perl::Critic::Policy::Community::SplitQuotedPattern>
+
+Quote the split() pattern argument with regex slashes
+
 =item L<Perl::Critic::Policy::Community::StrictWarnings>
 
 Always use L<strict> and L<warnings>, or a module that imports these
