@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 use Perl::Critic::Utils qw(:severities :classification :ppi);
-use parent 'Perl::Critic::Policy::ValuesAndExpressions::ProhibitArrayAssignAref';
+use parent 'Perl::Critic::Policy::Plicease::ProhibitArrayAssignAref';
 
-our $VERSION = 'v1.0.3';
+our $VERSION = 'v1.0.4';
 
 sub default_severity { $SEVERITY_MEDIUM }
 sub default_themes { 'community' }
@@ -29,7 +29,8 @@ brackets can be wrapped in parentheses for clarity.
  @array = [1, 2, 3];   # not ok
  @array = ([1, 2, 3]); # ok
 
-This policy is a subclass of the L<Perl::Critic::Pulp> policy
+This policy is a subclass of L<Perl::Critic::Policy::Plicease::ProhibitArrayAssignAref>,
+which is a fork of the L<Perl::Critic::Pulp> policy
 L<Perl::Critic::Policy::ValuesAndExpressions::ProhibitArrayAssignAref>, and
 performs the same function but in the C<community> theme.
 
