@@ -7,7 +7,7 @@ use Perl::Critic::Utils qw(:severities :classification :ppi);
 use Path::Tiny 'path';
 use parent 'Perl::Critic::Policy';
 
-our $VERSION = 'v1.0.3';
+our $VERSION = 'v1.0.4';
 
 use constant DESC => 'No package matching the module filename';
 use constant EXPL => 'A Perl module file is expected to contain a matching package name, so it can be used after loading it from the filesystem. A module file that doesn\'t contain a matching package name usually indicates an error.';
@@ -30,7 +30,7 @@ sub violates {
 	PKG: foreach my $package (@$packages) {
 		my $namespace = $package->namespace;
 		my $path_copy = $filepath;
-		foreach my $part (reverse split '::', $namespace) {
+		foreach my $part (reverse split /::/, $namespace) {
 			next PKG unless $part eq $path_copy->basename;
 			$path_copy = $path_copy->parent;
 		}
